@@ -161,7 +161,7 @@ class MsgTextWidget(QtWidgets.QWidget):
                     columnText = ""
                     alert = 0
                     for i in range(0,fieldInfo.count):
-                        fieldValue = Messaging.get(msg, fieldInfo, i)
+                        fieldValue = str(Messaging.get(msg, fieldInfo, i))
                         # if the value is what is given when we go off the end of an array, break.
                         if fieldInfo.type == "int" and fieldValue == "UNALLOCATED":
                             break
@@ -269,7 +269,7 @@ class MsgTreeWidget(TreeWidget):
                 columnText = ""
                 alert = 0
                 for i in range(0,fieldInfo.count):
-                    fieldValue = Messaging.get(msg, fieldInfo, i)
+                    fieldValue = str(Messaging.get(msg, fieldInfo, i))
                     # if the value is what is given when we go off the end of an array, break.
                     if fieldInfo.type == "int" and fieldValue == "UNALLOCATED":
                         break
